@@ -1,25 +1,25 @@
 import os.path
 
 from .base_producer import BlockingProducer
-from ..models import ArtifactUploadRequest, ArtifactMetadata, ArtifactBuildMetadata
+from ..models import ArtifactUploadRequest, ArtifactMetadata
 from ..models import QueueMessage
-from . import create_span_decorator
 from socket import gethostname
 from datetime import datetime
 import base64
 import os
 from ubai_client.apis import ArtifactApi
-from ubai_client.models import ArtifactInput, ArtifactStorage
+from ubai_client.models import ArtifactInput
+from otel_extensions import instrumented
 
 __all__ = [
     "UbaiArtifactUploadRequestProducer",
     "LocalUbaiArtifactUploadRequestProducer",
 ]
 
-span_decorator = create_span_decorator()
 
 MESSAGE_QUEUE_SIZE_LIMIT = 67108864  # 64MB
 
+
 class UbaiArtifactUploadRequestProducer:
     def __init__(self, url=None, producer_app_id: str = None):
         self.queue_name = "default"
@@ -27,17 +27,13 @@ class UbaiArtifactUploadRequestProducer:
         self.__client.queue_declare(queue=self.queue_name, durable=True)
         self.producer_app_id = producer_app_id
 
-    @span_decorator
+    @instrumented
     def upload_artifact(
-        self, artifact_file: str, metadata: dict, validate_metadata: bool=True
+        self, artifact_file: str, metadata: dict, validate_metadata: bool = True
     ):
         if validate_metadata:
             required_properties = ["branch", "stack", "build_number", "target"]
-            missing_keys = [
-                key
-                for key in required_properties
-                if key not in metadata
-            ]
+            missing_keys = [key for key in required_properties if key not in metadata]
             if len(missing_keys):
                 raise RuntimeError(
                     f"metadata is missing the following required properties: {','.join(missing_keys)}"
@@ -67,7 +63,7 @@ class UbaiArtifactUploadRequestProducer:
             )
             self.publish_artifact_upload_request(artifact_request)
 
-    @span_decorator
+    @instrumented
     def publish_artifact_upload_request(self, artifact_request: ArtifactUploadRequest):
         queue_message = QueueMessage(
             payload=artifact_request,
