@@ -7,6 +7,7 @@ from urllib import parse
 import click
 from typing import Iterable, Tuple
 from time import sleep
+from utf_queue_client.scripts import setup_telemetry
 
 
 @click.command()
@@ -52,25 +53,30 @@ def cli(
     client_id: str,
     retries: int = 3,
 ):
-    if username is None or password is None:
-        raise RuntimeError("username or password must be provided")
-    hostname = os.environ.get("UTF_QUEUE_HOSTNAME", "utf-queue-central.silabs.net")
-    scheme = os.environ.get("UTF_QUEUE_SCHEME", "amqps")
-    port = os.environ.get("UTF_QUEUE_PORT", "443")
-    virtual_host = os.environ.get("UTF_QUEUE_VIRTUAL_HOST", "%2f")
-    url = f"{scheme}://{username}:{parse.quote(password)}@{hostname}:{port}/{virtual_host}"
+    with setup_telemetry():
+        if username is None or password is None:
+            raise RuntimeError("username or password must be provided")
+        hostname = os.environ.get("UTF_QUEUE_HOSTNAME", "utf-queue-central.silabs.net")
+        scheme = os.environ.get("UTF_QUEUE_SCHEME", "amqps")
+        port = os.environ.get("UTF_QUEUE_PORT", "443")
+        virtual_host = os.environ.get("UTF_QUEUE_VIRTUAL_HOST", "%2f")
+        url = f"{scheme}://{username}:{parse.quote(password)}@{hostname}:{port}/{virtual_host}"
 
-    metadata_dict = {}
-    for key, value in metadata:
-        metadata_dict[key] = value
+        metadata_dict = {}
+        for key, value in metadata:
+            metadata_dict[key] = value
 
-    total_attempts = retries + 1
-    for try_index in range(total_attempts):
-        try:
-            client = UbaiArtifactUploadRequestProducer(url, client_id)
-            client.upload_artifact(file_path, metadata=metadata_dict)
-            break
-        except Exception:
-            if (try_index + 1) >= total_attempts:
-                raise
-            sleep(10)
+        total_attempts = retries + 1
+        for try_index in range(total_attempts):
+            try:
+                client = UbaiArtifactUploadRequestProducer(url, client_id)
+                client.upload_artifact(file_path, metadata=metadata_dict)
+                break
+            except Exception:
+                if (try_index + 1) >= total_attempts:
+                    raise
+                sleep(10)
+
+
+if __name__ == "__main__":
+    cli_entrypoint()
